Ark.StructAccess (ark v0.10.1)

Copy Markdown View Source

Summary

Functions

Using this module will allow to use the access macros and functions (Kernel.get_in/2, Kernel.put_in/2, etc.) with a struct.

Functions

__using__(_)

(macro)

Using this module will allow to use the access macros and functions (Kernel.get_in/2, Kernel.put_in/2, etc.) with a struct.