Summary
Functions
Using this module will allow to use the access macros and functions
(Kernel.get_in/2, Kernel.put_in/2, etc.) with a struct.
Functions
Using this module will allow to use the access macros and functions
(Kernel.get_in/2, Kernel.put_in/2, etc.) with a struct.